@@ -32,12 +32,29 @@
 #include "engine/commandresult.h"
 
 #include "ui/vaultcreationwizard.h"
-#include "ui/vaultconfigurationwizard.h"
+#include "ui/vaultimportingwizard.h"
+#include "ui/vaultconfigurationdialog.h"
 #include "ui/mountdialog.h"
 
 #include <functional>
 
+#include <config-plasma-vault.h>
+#ifdef HAVE_NETWORKMANAGER
 #include <NetworkManagerQt/Manager>
+#else
+namespace NetworkManager
+{
+    bool isNetworkingEnabled()
+    {
+        return true;
+    }
+
+    void setNetworkingEnabled(bool enabled)
+    {
+        Q_UNUSED(enabled);
+    }
+}
+#endif
 
 K_PLUGIN_FACTORY_WITH_JSON(PlasmaVaultServiceFactory,
                            "plasmavault.json",
@@ -108,13 +125,15 @@ PlasmaVaultService::PlasmaVaultService(QObject * parent, const QVariantList&)
     : KDEDModule(parent)
     , d(new Private())
 {
-    connect(this, &KDEDModule::moduleRegistered, this,
-            &PlasmaVaultService::slotRegistered);
+    connect(this, &KDEDModule::moduleRegistered,
+            this, &PlasmaVaultService::slotRegistered);
 
     connect(&d->kamd, &KActivities::Consumer::currentActivityChanged,
             this,     &PlasmaVaultService::onCurrentActivityChanged);
 
-    init();
+    for (const Device &device: Vault::availableDevices()) {
+        registerVault(new Vault(device, this));
+    }
 }
 
 
@@ -125,21 +144,11 @@ PlasmaVaultService::~PlasmaVaultService()
 
 
 
-void PlasmaVaultService::init()
-{
-    for (const Device &device: Vault::availableDevices()) {
-        registerVault(new Vault(device, this));
-    }
-}
-
-
-
 PlasmaVault::VaultInfoList PlasmaVaultService::availableDevices() const
 {
     PlasmaVault::VaultInfoList result;
     for (const auto &vault: d->knownVaults.values()) {
-        const auto vaultData = vault->info();
-        result << vaultData;
+        result << vault->info();
     }
     return result;
 }
@@ -158,6 +167,18 @@ void PlasmaVaultService::requestNewVault()
 
 
 
+void PlasmaVaultService::requestImportVault()
+{
+    const auto dialog = new VaultImportingWizard();
+
+    connect(dialog, &VaultImportingWizard::importedVault,
+            this,   &PlasmaVaultService::registerVault);
+
+    dialog->show();
+}
+
+
+
 void PlasmaVaultService::slotRegistered(const QDBusObjectPath &path)
 {
     if (path.path() == QLatin1String("/modules/plasmavault")) {
@@ -218,7 +239,7 @@ void PlasmaVaultService::forgetVault(Vault* vault)
 
 void PlasmaVaultService::onVaultStatusChanged(VaultInfo::Status status)
 {
-    const auto vault = qobject_cast<Vault*>(sender());
+    const auto vault = static_cast<Vault*>(sender());
 
     if (status == VaultInfo::Dismantled) {
         forgetVault(vault);
@@ -272,7 +293,7 @@ void PlasmaVaultService::onVaultStatusChanged(VaultInfo::Status status)
 
 void PlasmaVaultService::onVaultInfoChanged()
 {
-    const auto vault = qobject_cast<Vault*>(sender());
+    const auto vault = static_cast<Vault*>(sender());
     emit vaultChanged(vault->info());
 }
 
@@ -281,9 +302,7 @@ void PlasmaVaultService::onVaultInfoChanged()
 void PlasmaVaultService::onVaultMessageChanged(const QString &message)
 {
     Q_UNUSED(message);
-
-    const auto vault = qobject_cast<Vault*>(sender());
-
+    const auto vault = static_cast<Vault*>(sender());
     emit vaultChanged(vault->info());
 }
 
@@ -295,6 +314,8 @@ void showPasswordMountDialog(Vault *vault, const std::function<void()> &function
 }
 //^
 
+
+
 void PlasmaVaultService::openVault(const QString &device)
 {
     if (auto vault = d->vaultFor(device)) {
@@ -323,10 +344,7 @@ void PlasmaVaultService::closeVault(const QString &device)
 void PlasmaVaultService::configureVault(const QString &device)
 {
     if (auto vault = d->vaultFor(device)) {
-        const auto dialog = new VaultConfigurationWizard(vault);
-
-        // connect(dialog, &VaultConfigurationWizard::configurationChanged,
-        //         this,   &PlasmaVaultService::registerVault);
+        const auto dialog = new VaultConfigurationDialog(vault);
 
         dialog->show();
     }
